yt.fields.field\_plugin\_registry module
========================================

.. automodule:: yt.fields.field_plugin_registry
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
